# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import struct_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.dataflow.v1beta3",
    manifest={
        "JobMessageImportance",
        "JobMessage",
        "StructuredMessage",
        "AutoscalingEvent",
        "ListJobMessagesRequest",
        "ListJobMessagesResponse",
    },
)


class JobMessageImportance(proto.Enum):
    r"""Indicates the importance of the message."""
    JOB_MESSAGE_IMPORTANCE_UNKNOWN = 0
    JOB_MESSAGE_DEBUG = 1
    JOB_MESSAGE_DETAILED = 2
    JOB_MESSAGE_BASIC = 5
    JOB_MESSAGE_WARNING = 3
    JOB_MESSAGE_ERROR = 4


class JobMessage(proto.Message):
    r"""A particular message pertaining to a Dataflow job.

    Attributes:
        id (str):
            Deprecated.
        time (google.protobuf.timestamp_pb2.Timestamp):
            The timestamp of the message.
        message_text (str):
            The text of the message.
        message_importance (google.cloud.dataflow_v1beta3.types.JobMessageImportance):
            Importance level of the message.
    """

    id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    message_text: str = proto.Field(
        proto.STRING,
        number=3,
    )
    message_importance: "JobMessageImportance" = proto.Field(
        proto.ENUM,
        number=4,
        enum="JobMessageImportance",
    )


class StructuredMessage(proto.Message):
    r"""A rich message format, including a human readable string, a
    key for identifying the message, and structured data associated
    with the message for programmatic consumption.

    Attributes:
        message_text (str):
            Human-readable version of message.
        message_key (str):
            Identifier for this message type.  Used by
            external systems to internationalize or
            personalize message.
        parameters (MutableSequence[google.cloud.dataflow_v1beta3.types.StructuredMessage.Parameter]):
            The structured data associated with this
            message.
    """

    class Parameter(proto.Message):
        r"""Structured data associated with this message.

        Attributes:
            key (str):
                Key or name for this parameter.
            value (google.protobuf.struct_pb2.Value):
                Value for this parameter.
        """

        key: str = proto.Field(
            proto.STRING,
            number=1,
        )
        value: struct_pb2.Value = proto.Field(
            proto.MESSAGE,
            number=2,
            message=struct_pb2.Value,
        )

    message_text: str = proto.Field(
        proto.STRING,
        number=1,
    )
    message_key: str = proto.Field(
        proto.STRING,
        number=2,
    )
    parameters: MutableSequence[Parameter] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=Parameter,
    )


class AutoscalingEvent(proto.Message):
    r"""A structured message reporting an autoscaling decision made
    by the Dataflow service.

    Attributes:
        current_num_workers (int):
            The current number of workers the job has.
        target_num_workers (int):
            The target number of workers the worker pool
            wants to resize to use.
        event_type (google.cloud.dataflow_v1beta3.types.AutoscalingEvent.AutoscalingEventType):
            The type of autoscaling event to report.
        description (google.cloud.dataflow_v1beta3.types.StructuredMessage):
            A message describing why the system decided
            to adjust the current number of workers, why it
            failed, or why the system decided to not make
            any changes to the number of workers.
        time (google.protobuf.timestamp_pb2.Timestamp):
            The time this event was emitted to indicate a new target or
            current num_workers value.
        worker_pool (str):
            A short and friendly name for the worker pool
            this event refers to.
    """

    class AutoscalingEventType(proto.Enum):
        r"""Indicates the type of autoscaling event."""
        TYPE_UNKNOWN = 0
        TARGET_NUM_WORKERS_CHANGED = 1
        CURRENT_NUM_WORKERS_CHANGED = 2
        ACTUATION_FAILURE = 3
        NO_CHANGE = 4

    current_num_workers: int = proto.Field(
        proto.INT64,
        number=1,
    )
    target_num_workers: int = proto.Field(
        proto.INT64,
        number=2,
    )
    event_type: AutoscalingEventType = proto.Field(
        proto.ENUM,
        number=3,
        enum=AutoscalingEventType,
    )
    description: "StructuredMessage" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="StructuredMessage",
    )
    time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    worker_pool: str = proto.Field(
        proto.STRING,
        number=7,
    )


class ListJobMessagesRequest(proto.Message):
    r"""Request to list job messages. Up to max_results messages will be
    returned in the time range specified starting with the oldest
    messages first. If no time range is specified the results with start
    with the oldest message.

    Attributes:
        project_id (str):
            A project id.
        job_id (str):
            The job to get messages about.
        minimum_importance (google.cloud.dataflow_v1beta3.types.JobMessageImportance):
            Filter to only get messages with importance
            >= level
        page_size (int):
            If specified, determines the maximum number
            of messages to return.  If unspecified, the
            service may choose an appropriate default, or
            may return an arbitrarily large number of
            results.
        page_token (str):
            If supplied, this should be the value of next_page_token
            returned by an earlier call. This will cause the next page
            of results to be returned.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            If specified, return only messages with timestamps >=
            start_time. The default is the job creation time (i.e.
            beginning of messages).
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Return only messages with timestamps < end_time. The default
            is now (i.e. return up to the latest messages available).
        location (str):
            The [regional endpoint]
            (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints)
            that contains the job specified by job_id.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    job_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    minimum_importance: "JobMessageImportance" = proto.Field(
        proto.ENUM,
        number=3,
        enum="JobMessageImportance",
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=4,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=5,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    location: str = proto.Field(
        proto.STRING,
        number=8,
    )


class ListJobMessagesResponse(proto.Message):
    r"""Response to a request to list job messages.

    Attributes:
        job_messages (MutableSequence[google.cloud.dataflow_v1beta3.types.JobMessage]):
            Messages in ascending timestamp order.
        next_page_token (str):
            The token to obtain the next page of results
            if there are more.
        autoscaling_events (MutableSequence[google.cloud.dataflow_v1beta3.types.AutoscalingEvent]):
            Autoscaling events in ascending timestamp
            order.
    """

    @property
    def raw_page(self):
        return self

    job_messages: MutableSequence["JobMessage"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="JobMessage",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    autoscaling_events: MutableSequence["AutoscalingEvent"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="AutoscalingEvent",
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.rpc import status_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.dataflow_v1beta3.types import environment as gd_environment
from google.cloud.dataflow_v1beta3.types import jobs

__protobuf__ = proto.module(
    package="google.dataflow.v1beta3",
    manifest={
        "ParameterType",
        "LaunchFlexTemplateResponse",
        "ContainerSpec",
        "LaunchFlexTemplateParameter",
        "FlexTemplateRuntimeEnvironment",
        "LaunchFlexTemplateRequest",
        "RuntimeEnvironment",
        "ParameterMetadata",
        "TemplateMetadata",
        "SDKInfo",
        "RuntimeMetadata",
        "CreateJobFromTemplateRequest",
        "GetTemplateRequest",
        "GetTemplateResponse",
        "LaunchTemplateParameters",
        "LaunchTemplateRequest",
        "LaunchTemplateResponse",
        "InvalidTemplateParameters",
        "DynamicTemplateLaunchParams",
    },
)


class ParameterType(proto.Enum):
    r"""ParameterType specifies what kind of input we need for this
    parameter.
    """
    DEFAULT = 0
    TEXT = 1
    GCS_READ_BUCKET = 2
    GCS_WRITE_BUCKET = 3
    GCS_READ_FILE = 4
    GCS_WRITE_FILE = 5
    GCS_READ_FOLDER = 6
    GCS_WRITE_FOLDER = 7
    PUBSUB_TOPIC = 8
    PUBSUB_SUBSCRIPTION = 9


class LaunchFlexTemplateResponse(proto.Message):
    r"""Response to the request to launch a job from Flex Template.

    Attributes:
        job (google.cloud.dataflow_v1beta3.types.Job):
            The job that was launched, if the request was
            not a dry run and the job was successfully
            launched.
    """

    job: jobs.Job = proto.Field(
        proto.MESSAGE,
        number=1,
        message=jobs.Job,
    )


class ContainerSpec(proto.Message):
    r"""Container Spec.

    Attributes:
        image (str):
            Name of the docker container image. E.g.,
            gcr.io/project/some-image
        metadata (google.cloud.dataflow_v1beta3.types.TemplateMetadata):
            Metadata describing a template including
            description and validation rules.
        sdk_info (google.cloud.dataflow_v1beta3.types.SDKInfo):
            Required. SDK info of the Flex Template.
        default_environment (google.cloud.dataflow_v1beta3.types.FlexTemplateRuntimeEnvironment):
            Default runtime environment for the job.
    """

    image: str = proto.Field(
        proto.STRING,
        number=1,
    )
    metadata: "TemplateMetadata" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="TemplateMetadata",
    )
    sdk_info: "SDKInfo" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="SDKInfo",
    )
    default_environment: "FlexTemplateRuntimeEnvironment" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="FlexTemplateRuntimeEnvironment",
    )


class LaunchFlexTemplateParameter(proto.Message):
    r"""Launch FlexTemplate Parameter.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        job_name (str):
            Required. The job name to use for the created
            job. For update job request, job name should be
            same as the existing running job.
        container_spec (google.cloud.dataflow_v1beta3.types.ContainerSpec):
            Spec about the container image to launch.

            This field is a member of `oneof`_ ``template``.
        container_spec_gcs_path (str):
            Cloud Storage path to a file with json
            serialized ContainerSpec as content.

            This field is a member of `oneof`_ ``template``.
        parameters (MutableMapping[str, str]):
            The parameters for FlexTemplate. Ex. {"num_workers":"5"}
        launch_options (MutableMapping[str, str]):
            Launch options for this flex template job.
            This is a common set of options across languages
            and templates. This should not be used to pass
            job parameters.
        environment (google.cloud.dataflow_v1beta3.types.FlexTemplateRuntimeEnvironment):
            The runtime environment for the FlexTemplate
            job
        update (bool):
            Set this to true if you are sending a request
            to update a running streaming job. When set, the
            job name should be the same as the running job.
        transform_name_mappings (MutableMapping[str, str]):
            Use this to pass transform_name_mappings for streaming
            update jobs. Ex:{"oldTransformName":"newTransformName",...}'
    """

    job_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    container_spec: "ContainerSpec" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="template",
        message="ContainerSpec",
    )
    container_spec_gcs_path: str = proto.Field(
        proto.STRING,
        number=5,
        oneof="template",
    )
    parameters: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=2,
    )
    launch_options: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=6,
    )
    environment: "FlexTemplateRuntimeEnvironment" = proto.Field(
        proto.MESSAGE,
        number=7,
        message="FlexTemplateRuntimeEnvironment",
    )
    update: bool = proto.Field(
        proto.BOOL,
        number=8,
    )
    transform_name_mappings: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=9,
    )


class FlexTemplateRuntimeEnvironment(proto.Message):
    r"""The environment values to be set at runtime for flex
    template.

    Attributes:
        num_workers (int):
            The initial number of Google Compute Engine
            instances for the job.
        max_workers (int):
            The maximum number of Google Compute Engine
            instances to be made available to your pipeline
            during execution, from 1 to 1000.
        zone (str):
            The Compute Engine `availability
            zone <https://cloud.google.com/compute/docs/regions-zones/regions-zones>`__
            for launching worker instances to run your pipeline. In the
            future, worker_zone will take precedence.
        service_account_email (str):
            The email address of the service account to
            run the job as.
        temp_location (str):
            The Cloud Storage path to use for temporary files. Must be a
            valid Cloud Storage URL, beginning with ``gs://``.
        machine_type (str):
            The machine type to use for the job. Defaults
            to the value from the template if not specified.
        additional_experiments (MutableSequence[str]):
            Additional experiment flags for the job.
        network (str):
            Network to which VMs will be assigned.  If
            empty or unspecified, the service will use the
            network "default".
        subnetwork (str):
            Subnetwork to which VMs will be assigned, if desired. You
            can specify a subnetwork using either a complete URL or an
            abbreviated path. Expected to be of the form
            "https://www.googleapis.com/compute/v1/projects/HOST_PROJECT_ID/regions/REGION/subnetworks/SUBNETWORK"
            or "regions/REGION/subnetworks/SUBNETWORK". If the
            subnetwork is located in a Shared VPC network, you must use
            the complete URL.
        additional_user_labels (MutableMapping[str, str]):
            Additional user labels to be specified for the job. Keys and
            values must follow the restrictions specified in the
            `labeling
            restrictions <https://cloud.google.com/compute/docs/labeling-resources#restrictions>`__
            page. An object containing a list of "key": value pairs.
            Example: { "name": "wrench", "mass": "1kg", "count": "3" }.
        kms_key_name (str):
            Name for the Cloud KMS key for the job.
            Key format is:
            projects/<project>/locations/<location>/keyRings/<keyring>/cryptoKeys/<key>
        ip_configuration (google.cloud.dataflow_v1beta3.types.WorkerIPAddressConfiguration):
            Configuration for VM IPs.
        worker_region (str):
            The Compute Engine region
            (https://cloud.google.com/compute/docs/regions-zones/regions-zones)
            in which worker processing should occur, e.g. "us-west1".
            Mutually exclusive with worker_zone. If neither
            worker_region nor worker_zone is specified, default to the
            control plane's region.
        worker_zone (str):
            The Compute Engine zone
            (https://cloud.google.com/compute/docs/regions-zones/regions-zones)
            in which worker processing should occur, e.g. "us-west1-a".
            Mutually exclusive with worker_region. If neither
            worker_region nor worker_zone is specified, a zone in the
            control plane's region is chosen based on available
            capacity. If both ``worker_zone`` and ``zone`` are set,
            ``worker_zone`` takes precedence.
        enable_streaming_engine (bool):
            Whether to enable Streaming Engine for the
            job.
        flexrs_goal (google.cloud.dataflow_v1beta3.types.FlexResourceSchedulingGoal):
            Set FlexRS goal for the job.
            https://cloud.google.com/dataflow/docs/guides/flexrs
        staging_location (str):
            The Cloud Storage path for staging local files. Must be a
            valid Cloud Storage URL, beginning with ``gs://``.
        sdk_container_image (str):
            Docker registry location of container image
            to use for the 'worker harness. Default is the
            container for the version of the SDK. Note this
            field is only valid for portable pipelines.
        disk_size_gb (int):
            Worker disk size, in gigabytes.
        autoscaling_algorithm (google.cloud.dataflow_v1beta3.types.AutoscalingAlgorithm):
            The algorithm to use for autoscaling
        dump_heap_on_oom (bool):
            If true, save a heap dump before killing a
            thread or process which is GC thrashing or out
            of memory. The location of the heap file will
            either be echoed back to the user, or the user
            will be given the opportunity to download the
            heap file.
        save_heap_dumps_to_gcs_path (str):
            Cloud Storage bucket (directory) to upload heap dumps to the
            given location. Enabling this implies that heap dumps should
            be generated on OOM (dump_heap_on_oom is set to true).
        launcher_machine_type (str):
            The machine type to use for launching the
            job. The default is n1-standard-1.
    """

    num_workers: int = proto.Field(
        proto.INT32,
        number=1,
    )
    max_workers: int = proto.Field(
        proto.INT32,
        number=2,
    )
    zone: str = proto.Field(
        proto.STRING,
        number=3,
    )
    service_account_email: str = proto.Field(
        proto.STRING,
        number=4,
    )
    temp_location: str = proto.Field(
        proto.STRING,
        number=5,
    )
    machine_type: str = proto.Field(
        proto.STRING,
        number=6,
    )
    additional_experiments: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    network: str = proto.Field(
        proto.STRING,
        number=8,
    )
    subnetwork: str = proto.Field(
        proto.STRING,
        number=9,
    )
    additional_user_labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=10,
    )
    kms_key_name: str = proto.Field(
        proto.STRING,
        number=11,
    )
    ip_configuration: gd_environment.WorkerIPAddressConfiguration = proto.Field(
        proto.ENUM,
        number=12,
        enum=gd_environment.WorkerIPAddressConfiguration,
    )
    worker_region: str = proto.Field(
        proto.STRING,
        number=13,
    )
    worker_zone: str = proto.Field(
        proto.STRING,
        number=14,
    )
    enable_streaming_engine: bool = proto.Field(
        proto.BOOL,
        number=15,
    )
    flexrs_goal: gd_environment.FlexResourceSchedulingGoal = proto.Field(
        proto.ENUM,
        number=16,
        enum=gd_environment.FlexResourceSchedulingGoal,
    )
    staging_location: str = proto.Field(
        proto.STRING,
        number=17,
    )
    sdk_container_image: str = proto.Field(
        proto.STRING,
        number=18,
    )
    disk_size_gb: int = proto.Field(
        proto.INT32,
        number=20,
    )
    autoscaling_algorithm: gd_environment.AutoscalingAlgorithm = proto.Field(
        proto.ENUM,
        number=21,
        enum=gd_environment.AutoscalingAlgorithm,
    )
    dump_heap_on_oom: bool = proto.Field(
        proto.BOOL,
        number=22,
    )
    save_heap_dumps_to_gcs_path: str = proto.Field(
        proto.STRING,
        number=23,
    )
    launcher_machine_type: str = proto.Field(
        proto.STRING,
        number=24,
    )


class LaunchFlexTemplateRequest(proto.Message):
    r"""A request to launch a Cloud Dataflow job from a FlexTemplate.

    Attributes:
        project_id (str):
            Required. The ID of the Cloud Platform
            project that the job belongs to.
        launch_parameter (google.cloud.dataflow_v1beta3.types.LaunchFlexTemplateParameter):
            Required. Parameter to launch a job form Flex
            Template.
        location (str):
            Required. The [regional endpoint]
            (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints)
            to which to direct the request. E.g., us-central1, us-west1.
        validate_only (bool):
            If true, the request is validated but not
            actually executed. Defaults to false.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    launch_parameter: "LaunchFlexTemplateParameter" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="LaunchFlexTemplateParameter",
    )
    location: str = proto.Field(
        proto.STRING,
        number=3,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


class RuntimeEnvironment(proto.Message):
    r"""The environment values to set at runtime.

    Attributes:
        num_workers (int):
            The initial number of Google Compute Engine
            instnaces for the job.
        max_workers (int):
            The maximum number of Google Compute Engine
            instances to be made available to your pipeline
            during execution, from 1 to 1000.
        zone (str):
            The Compute Engine `availability
            zone <https://cloud.google.com/compute/docs/regions-zones/regions-zones>`__
            for launching worker instances to run your pipeline. In the
            future, worker_zone will take precedence.
        service_account_email (str):
            The email address of the service account to
            run the job as.
        temp_location (str):
            The Cloud Storage path to use for temporary files. Must be a
            valid Cloud Storage URL, beginning with ``gs://``.
        bypass_temp_dir_validation (bool):
            Whether to bypass the safety checks for the
            job's temporary directory. Use with caution.
        machine_type (str):
            The machine type to use for the job. Defaults
            to the value from the template if not specified.
        additional_experiments (MutableSequence[str]):
            Additional experiment flags for the job, specified with the
            ``--experiments`` option.
        network (str):
            Network to which VMs will be assigned.  If
            empty or unspecified, the service will use the
            network "default".
        subnetwork (str):
            Subnetwork to which VMs will be assigned, if desired. You
            can specify a subnetwork using either a complete URL or an
            abbreviated path. Expected to be of the form
            "https://www.googleapis.com/compute/v1/projects/HOST_PROJECT_ID/regions/REGION/subnetworks/SUBNETWORK"
            or "regions/REGION/subnetworks/SUBNETWORK". If the
            subnetwork is located in a Shared VPC network, you must use
            the complete URL.
        additional_user_labels (MutableMapping[str, str]):
            Additional user labels to be specified for the job. Keys and
            values should follow the restrictions specified in the
            `labeling
            restrictions <https://cloud.google.com/compute/docs/labeling-resources#restrictions>`__
            page. An object containing a list of "key": value pairs.
            Example: { "name": "wrench", "mass": "1kg", "count": "3" }.
        kms_key_name (str):
            Name for the Cloud KMS key for the job.
            Key format is:
            projects/<project>/locations/<location>/keyRings/<keyring>/cryptoKeys/<key>
        ip_configuration (google.cloud.dataflow_v1beta3.types.WorkerIPAddressConfiguration):
            Configuration for VM IPs.
        worker_region (str):
            The Compute Engine region
            (https://cloud.google.com/compute/docs/regions-zones/regions-zones)
            in which worker processing should occur, e.g. "us-west1".
            Mutually exclusive with worker_zone. If neither
            worker_region nor worker_zone is specified, default to the
            control plane's region.
        worker_zone (str):
            The Compute Engine zone
            (https://cloud.google.com/compute/docs/regions-zones/regions-zones)
            in which worker processing should occur, e.g. "us-west1-a".
            Mutually exclusive with worker_region. If neither
            worker_region nor worker_zone is specified, a zone in the
            control plane's region is chosen based on available
            capacity. If both ``worker_zone`` and ``zone`` are set,
            ``worker_zone`` takes precedence.
        enable_streaming_engine (bool):
            Whether to enable Streaming Engine for the
            job.
    """

    num_workers: int = proto.Field(
        proto.INT32,
        number=11,
    )
    max_workers: int = proto.Field(
        proto.INT32,
        number=1,
    )
    zone: str = proto.Field(
        proto.STRING,
        number=2,
    )
    service_account_email: str = proto.Field(
        proto.STRING,
        number=3,
    )
    temp_location: str = proto.Field(
        proto.STRING,
        number=4,
    )
    bypass_temp_dir_validation: bool = proto.Field(
        proto.BOOL,
        number=5,
    )
    machine_type: str = proto.Field(
        proto.STRING,
        number=6,
    )
    additional_experiments: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    network: str = proto.Field(
        proto.STRING,
        number=8,
    )
    subnetwork: str = proto.Field(
        proto.STRING,
        number=9,
    )
    additional_user_labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=10,
    )
    kms_key_name: str = proto.Field(
        proto.STRING,
        number=12,
    )
    ip_configuration: gd_environment.WorkerIPAddressConfiguration = proto.Field(
        proto.ENUM,
        number=14,
        enum=gd_environment.WorkerIPAddressConfiguration,
    )
    worker_region: str = proto.Field(
        proto.STRING,
        number=15,
    )
    worker_zone: str = proto.Field(
        proto.STRING,
        number=16,
    )
    enable_streaming_engine: bool = proto.Field(
        proto.BOOL,
        number=17,
    )


class ParameterMetadata(proto.Message):
    r"""Metadata for a specific parameter.

    Attributes:
        name (str):
            Required. The name of the parameter.
        label (str):
            Required. The label to display for the
            parameter.
        help_text (str):
            Required. The help text to display for the
            parameter.
        is_optional (bool):
            Optional. Whether the parameter is optional.
            Defaults to false.
        regexes (MutableSequence[str]):
            Optional. Regexes that the parameter must
            match.
        param_type (google.cloud.dataflow_v1beta3.types.ParameterType):
            Optional. The type of the parameter.
            Used for selecting input picker.
        custom_metadata (MutableMapping[str, str]):
            Optional. Additional metadata for describing
            this parameter.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    label: str = proto.Field(
        proto.STRING,
        number=2,
    )
    help_text: str = proto.Field(
        proto.STRING,
        number=3,
    )
    is_optional: bool = proto.Field(
        proto.BOOL,
        number=4,
    )
    regexes: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    param_type: "ParameterType" = proto.Field(
        proto.ENUM,
        number=6,
        enum="ParameterType",
    )
    custom_metadata: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=7,
    )


class TemplateMetadata(proto.Message):
    r"""Metadata describing a template.

    Attributes:
        name (str):
            Required. The name of the template.
        description (str):
            Optional. A description of the template.
        parameters (MutableSequence[google.cloud.dataflow_v1beta3.types.ParameterMetadata]):
            The parameters for the template.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    parameters: MutableSequence["ParameterMetadata"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="ParameterMetadata",
    )


class SDKInfo(proto.Message):
    r"""SDK Information.

    Attributes:
        language (google.cloud.dataflow_v1beta3.types.SDKInfo.Language):
            Required. The SDK Language.
        version (str):
            Optional. The SDK version.
    """

    class Language(proto.Enum):
        r"""SDK Language."""
        UNKNOWN = 0
        JAVA = 1
        PYTHON = 2

    language: Language = proto.Field(
        proto.ENUM,
        number=1,
        enum=Language,
    )
    version: str = proto.Field(
        proto.STRING,
        number=2,
    )


class RuntimeMetadata(proto.Message):
    r"""RuntimeMetadata describing a runtime environment.

    Attributes:
        sdk_info (google.cloud.dataflow_v1beta3.types.SDKInfo):
            SDK Info for the template.
        parameters (MutableSequence[google.cloud.dataflow_v1beta3.types.ParameterMetadata]):
            The parameters for the template.
    """

    sdk_info: "SDKInfo" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="SDKInfo",
    )
    parameters: MutableSequence["ParameterMetadata"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="ParameterMetadata",
    )


class CreateJobFromTemplateRequest(proto.Message):
    r"""A request to create a Cloud Dataflow job from a template.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        project_id (str):
            Required. The ID of the Cloud Platform
            project that the job belongs to.
        job_name (str):
            Required. The job name to use for the created
            job.
        gcs_path (str):
            Required. A Cloud Storage path to the template from which to
            create the job. Must be a valid Cloud Storage URL, beginning
            with ``gs://``.

            This field is a member of `oneof`_ ``template``.
        parameters (MutableMapping[str, str]):
            The runtime parameters to pass to the job.
        environment (google.cloud.dataflow_v1beta3.types.RuntimeEnvironment):
            The runtime environment for the job.
        location (str):
            The [regional endpoint]
            (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints)
            to which to direct the request.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    job_name: str = proto.Field(
        proto.STRING,
        number=4,
    )
    gcs_path: str = proto.Field(
        proto.STRING,
        number=2,
        oneof="template",
    )
    parameters: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=3,
    )
    environment: "RuntimeEnvironment" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="RuntimeEnvironment",
    )
    location: str = proto.Field(
        proto.STRING,
        number=6,
    )


class GetTemplateRequest(proto.Message):
    r"""A request to retrieve a Cloud Dataflow job template.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        project_id (str):
            Required. The ID of the Cloud Platform
            project that the job belongs to.
        gcs_path (str):
            Required. A Cloud Storage path to the
            template from which to create the job.
            Must be valid Cloud Storage URL, beginning with
            'gs://'.

            This field is a member of `oneof`_ ``template``.
        view (google.cloud.dataflow_v1beta3.types.GetTemplateRequest.TemplateView):
            The view to retrieve. Defaults to METADATA_ONLY.
        location (str):
            The [regional endpoint]
            (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints)
            to which to direct the request.
    """

    class TemplateView(proto.Enum):
        r"""The various views of a template that may be retrieved."""
        METADATA_ONLY = 0

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    gcs_path: str = proto.Field(
        proto.STRING,
        number=2,
        oneof="template",
    )
    view: TemplateView = proto.Field(
        proto.ENUM,
        number=3,
        enum=TemplateView,
    )
    location: str = proto.Field(
        proto.STRING,
        number=4,
    )


class GetTemplateResponse(proto.Message):
    r"""The response to a GetTemplate request.

    Attributes:
        status (google.rpc.status_pb2.Status):
            The status of the get template request. Any problems with
            the request will be indicated in the error_details.
        metadata (google.cloud.dataflow_v1beta3.types.TemplateMetadata):
            The template metadata describing the template
            name, available parameters, etc.
        template_type (google.cloud.dataflow_v1beta3.types.GetTemplateResponse.TemplateType):
            Template Type.
        runtime_metadata (google.cloud.dataflow_v1beta3.types.RuntimeMetadata):
            Describes the runtime metadata with SDKInfo
            and available parameters.
    """

    class TemplateType(proto.Enum):
        r"""Template Type."""
        UNKNOWN = 0
        LEGACY = 1
        FLEX = 2

    status: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=1,
        message=status_pb2.Status,
    )
    metadata: "TemplateMetadata" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="TemplateMetadata",
    )
    template_type: TemplateType = proto.Field(
        proto.ENUM,
        number=3,
        enum=TemplateType,
    )
    runtime_metadata: "RuntimeMetadata" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="RuntimeMetadata",
    )


class LaunchTemplateParameters(proto.Message):
    r"""Parameters to provide to the template being launched.

    Attributes:
        job_name (str):
            Required. The job name to use for the created
            job.
        parameters (MutableMapping[str, str]):
            The runtime parameters to pass to the job.
        environment (google.cloud.dataflow_v1beta3.types.RuntimeEnvironment):
            The runtime environment for the job.
        update (bool):
            If set, replace the existing pipeline with
            the name specified by jobName with this
            pipeline, preserving state.
        transform_name_mapping (MutableMapping[str, str]):
            Only applicable when updating a pipeline. Map
            of transform name prefixes of the job to be
            replaced to the corresponding name prefixes of
            the new job.
    """

    job_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    parameters: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=2,
    )
    environment: "RuntimeEnvironment" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="RuntimeEnvironment",
    )
    update: bool = proto.Field(
        proto.BOOL,
        number=4,
    )
    transform_name_mapping: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=5,
    )


class LaunchTemplateRequest(proto.Message):
    r"""A request to launch a template.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        project_id (str):
            Required. The ID of the Cloud Platform
            project that the job belongs to.
        validate_only (bool):
            If true, the request is validated but not
            actually executed. Defaults to false.
        gcs_path (str):
            A Cloud Storage path to the template from
            which to create the job.
            Must be valid Cloud Storage URL, beginning with
            'gs://'.

            This field is a member of `oneof`_ ``template``.
        dynamic_template (google.cloud.dataflow_v1beta3.types.DynamicTemplateLaunchParams):
            Params for launching a dynamic template.

            This field is a member of `oneof`_ ``template``.
        launch_parameters (google.cloud.dataflow_v1beta3.types.LaunchTemplateParameters):
            The parameters of the template to launch.
            This should be part of the body of the POST
            request.
        location (str):
            The [regional endpoint]
            (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints)
            to which to direct the request.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=2,
    )
    gcs_path: str = proto.Field(
        proto.STRING,
        number=3,
        oneof="template",
    )
    dynamic_template: "DynamicTemplateLaunchParams" = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="template",
        message="DynamicTemplateLaunchParams",
    )
    launch_parameters: "LaunchTemplateParameters" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="LaunchTemplateParameters",
    )
    location: str = proto.Field(
        proto.STRING,
        number=5,
    )


class LaunchTemplateResponse(proto.Message):
    r"""Response to the request to launch a template.

    Attributes:
        job (google.cloud.dataflow_v1beta3.types.Job):
            The job that was launched, if the request was
            not a dry run and the job was successfully
            launched.
    """

    job: jobs.Job = proto.Field(
        proto.MESSAGE,
        number=1,
        message=jobs.Job,
    )


class InvalidTemplateParameters(proto.Message):
    r"""Used in the error_details field of a google.rpc.Status message, this
    indicates problems with the template parameter.

    Attributes:
        parameter_violations (MutableSequence[google.cloud.dataflow_v1beta3.types.InvalidTemplateParameters.ParameterViolation]):
            Describes all parameter violations in a
            template request.
    """

    class ParameterViolation(proto.Message):
        r"""A specific template-parameter violation.

        Attributes:
            parameter (str):
                The parameter that failed to validate.
            description (str):
                A description of why the parameter failed to
                validate.
        """

        parameter: str = proto.Field(
            proto.STRING,
            number=1,
        )
        description: str = proto.Field(
            proto.STRING,
            number=2,
        )

    parameter_violations: MutableSequence[ParameterViolation] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ParameterViolation,
    )


class DynamicTemplateLaunchParams(proto.Message):
    r"""Params which should be passed when launching a dynamic
    template.

    Attributes:
        gcs_path (str):
            Path to dynamic template spec file on Cloud
            Storage. The file must be a Json serialized
            DynamicTemplateFieSpec object.
        staging_location (str):
            Cloud Storage path for staging dependencies. Must be a valid
            Cloud Storage URL, beginning with ``gs://``.
    """

    gcs_path: str = proto.Field(
        proto.STRING,
        number=1,
    )
    staging_location: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import any_pb2  # type: ignore
from google.protobuf import struct_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.dataflow.v1beta3",
    manifest={
        "JobType",
        "FlexResourceSchedulingGoal",
        "TeardownPolicy",
        "DefaultPackageSet",
        "AutoscalingAlgorithm",
        "WorkerIPAddressConfiguration",
        "ShuffleMode",
        "Environment",
        "Package",
        "Disk",
        "WorkerSettings",
        "TaskRunnerSettings",
        "AutoscalingSettings",
        "SdkHarnessContainerImage",
        "WorkerPool",
        "DebugOptions",
    },
)


class JobType(proto.Enum):
    r"""Specifies the processing model used by a
    [google.dataflow.v1beta3.Job], which determines the way the Job is
    managed by the Cloud Dataflow service (how workers are scheduled,
    how inputs are sharded, etc).
    """
    JOB_TYPE_UNKNOWN = 0
    JOB_TYPE_BATCH = 1
    JOB_TYPE_STREAMING = 2


class FlexResourceSchedulingGoal(proto.Enum):
    r"""Specifies the resource to optimize for in Flexible Resource
    Scheduling.
    """
    FLEXRS_UNSPECIFIED = 0
    FLEXRS_SPEED_OPTIMIZED = 1
    FLEXRS_COST_OPTIMIZED = 2


class TeardownPolicy(proto.Enum):
    r"""Specifies what happens to a resource when a Cloud Dataflow
    [google.dataflow.v1beta3.Job][google.dataflow.v1beta3.Job] has
    completed.
    """
    TEARDOWN_POLICY_UNKNOWN = 0
    TEARDOWN_ALWAYS = 1
    TEARDOWN_ON_SUCCESS = 2
    TEARDOWN_NEVER = 3


class DefaultPackageSet(proto.Enum):
    r"""The default set of packages to be staged on a pool of
    workers.
    """
    DEFAULT_PACKAGE_SET_UNKNOWN = 0
    DEFAULT_PACKAGE_SET_NONE = 1
    DEFAULT_PACKAGE_SET_JAVA = 2
    DEFAULT_PACKAGE_SET_PYTHON = 3


class AutoscalingAlgorithm(proto.Enum):
    r"""Specifies the algorithm used to determine the number of
    worker processes to run at any given point in time, based on the
    amount of data left to process, the number of workers, and how
    quickly existing workers are processing data.
    """
    AUTOSCALING_ALGORITHM_UNKNOWN = 0
    AUTOSCALING_ALGORITHM_NONE = 1
    AUTOSCALING_ALGORITHM_BASIC = 2


class WorkerIPAddressConfiguration(proto.Enum):
    r"""Specifies how IP addresses should be allocated to the worker
    machines.
    """
    WORKER_IP_UNSPECIFIED = 0
    WORKER_IP_PUBLIC = 1
    WORKER_IP_PRIVATE = 2


class ShuffleMode(proto.Enum):
    r"""Specifies the shuffle mode used by a [google.dataflow.v1beta3.Job],
    which determines the approach data is shuffled during processing.
    More details in:
    https://cloud.google.com/dataflow/docs/guides/deploying-a-pipeline#dataflow-shuffle
    """
    SHUFFLE_MODE_UNSPECIFIED = 0
    VM_BASED = 1
    SERVICE_BASED = 2


class Environment(proto.Message):
    r"""Describes the environment in which a Dataflow Job runs.

    Attributes:
        temp_storage_prefix (str):
            The prefix of the resources the system should use for
            temporary storage. The system will append the suffix
            "/temp-{JOBNAME} to this resource prefix, where {JOBNAME} is
            the value of the job_name field. The resulting bucket and
            object prefix is used as the prefix of the resources used to
            store temporary data needed during the job execution. NOTE:
            This will override the value in taskrunner_settings. The
            supported resource type is:

            Google Cloud Storage:

            storage.googleapis.com/{bucket}/{object}
            bucket.storage.googleapis.com/{object}
        cluster_manager_api_service (str):
            The type of cluster manager API to use.  If
            unknown or unspecified, the service will attempt
            to choose a reasonable default.  This should be
            in the form of the API service name, e.g.
            "compute.googleapis.com".
        experiments (MutableSequence[str]):
            The list of experiments to enable. This field should be used
            for SDK related experiments and not for service related
            experiments. The proper field for service related
            experiments is service_options.
        service_options (MutableSequence[str]):
            The list of service options to enable. This
            field should be used for service related
            experiments only. These experiments, when
            graduating to GA, should be replaced by
            dedicated fields or become default (i.e. always
            on).
        service_kms_key_name (str):
            If set, contains the Cloud KMS key identifier used to
            encrypt data at rest, AKA a Customer Managed Encryption Key
            (CMEK).

            Format:
            projects/PROJECT_ID/locations/LOCATION/keyRings/KEY_RING/cryptoKeys/KEY
        worker_pools (MutableSequence[google.cloud.dataflow_v1beta3.types.WorkerPool]):
            The worker pools. At least one "harness"
            worker pool must be specified in order for the
            job to have workers.
        user_agent (google.protobuf.struct_pb2.Struct):
            A description of the process that generated
            the request.
        version (google.protobuf.struct_pb2.Struct):
            A structure describing which components and
            their versions of the service are required in
            order to run the job.
        dataset (str):
            The dataset for the current project where
            various workflow related tables are stored.

            The supported resource type is:

            Google BigQuery:
              bigquery.googleapis.com/{dataset}
        sdk_pipeline_options (google.protobuf.struct_pb2.Struct):
            The Cloud Dataflow SDK pipeline options
            specified by the user. These options are passed
            through the service and are used to recreate the
            SDK pipeline options on the worker in a language
            agnostic and platform independent way.
        internal_experiments (google.protobuf.any_pb2.Any):
            Experimental settings.
        service_account_email (str):
            Identity to run virtual machines as. Defaults
            to the default account.
        flex_resource_scheduling_goal (google.cloud.dataflow_v1beta3.types.FlexResourceSchedulingGoal):
            Which Flexible Resource Scheduling mode to
            run in.
        worker_region (str):
            The Compute Engine region
            (https://cloud.google.com/compute/docs/regions-zones/regions-zones)
            in which worker processing should occur, e.g. "us-west1".
            Mutually exclusive with worker_zone. If neither
            worker_region nor worker_zone is specified, default to the
            control plane's region.
        worker_zone (str):
            The Compute Engine zone
            (https://cloud.google.com/compute/docs/regions-zones/regions-zones)
            in which worker processing should occur, e.g. "us-west1-a".
            Mutually exclusive with worker_region. If neither
            worker_region nor worker_zone is specified, a zone in the
            control plane's region is chosen based on available
            capacity.
        shuffle_mode (google.cloud.dataflow_v1beta3.types.ShuffleMode):
            Output only. The shuffle mode used for the
            job.
        debug_options (google.cloud.dataflow_v1beta3.types.DebugOptions):
            Any debugging options to be supplied to the
            job.
    """

    temp_storage_prefix: str = proto.Field(
        proto.STRING,
        number=1,
    )
    cluster_manager_api_service: str = proto.Field(
        proto.STRING,
        number=2,
    )
    experiments: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    service_options: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=16,
    )
    service_kms_key_name: str = proto.Field(
        proto.STRING,
        number=12,
    )
    worker_pools: MutableSequence["WorkerPool"] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="WorkerPool",
    )
    user_agent: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=5,
        message=struct_pb2.Struct,
    )
    version: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=6,
        message=struct_pb2.Struct,
    )
    dataset: str = proto.Field(
        proto.STRING,
        number=7,
    )
    sdk_pipeline_options: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=8,
        message=struct_pb2.Struct,
    )
    internal_experiments: any_pb2.Any = proto.Field(
        proto.MESSAGE,
        number=9,
        message=any_pb2.Any,
    )
    service_account_email: str = proto.Field(
        proto.STRING,
        number=10,
    )
    flex_resource_scheduling_goal: "FlexResourceSchedulingGoal" = proto.Field(
        proto.ENUM,
        number=11,
        enum="FlexResourceSchedulingGoal",
    )
    worker_region: str = proto.Field(
        proto.STRING,
        number=13,
    )
    worker_zone: str = proto.Field(
        proto.STRING,
        number=14,
    )
    shuffle_mode: "ShuffleMode" = proto.Field(
        proto.ENUM,
        number=15,
        enum="ShuffleMode",
    )
    debug_options: "DebugOptions" = proto.Field(
        proto.MESSAGE,
        number=17,
        message="DebugOptions",
    )


class Package(proto.Message):
    r"""The packages that must be installed in order for a worker to
    run the steps of the Cloud Dataflow job that will be assigned to
    its worker pool.

    This is the mechanism by which the Cloud Dataflow SDK causes
    code to be loaded onto the workers. For example, the Cloud
    Dataflow Java SDK might use this to install jars containing the
    user's code and all of the various dependencies (libraries, data
    files, etc.) required in order for that code to run.

    Attributes:
        name (str):
            The name of the package.
        location (str):
            The resource to read the package from. The
            supported resource type is:
            Google Cloud Storage:

              storage.googleapis.com/{bucket}
              bucket.storage.googleapis.com/
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    location: str = proto.Field(
        proto.STRING,
        number=2,
    )


class Disk(proto.Message):
    r"""Describes the data disk used by a workflow job.

    Attributes:
        size_gb (int):
            Size of disk in GB.  If zero or unspecified,
            the service will attempt to choose a reasonable
            default.
        disk_type (str):
            Disk storage type, as defined by Google
            Compute Engine.  This must be a disk type
            appropriate to the project and zone in which the
            workers will run.  If unknown or unspecified,
            the service will attempt to choose a reasonable
            default.

            For example, the standard persistent disk type
            is a resource name typically ending in
            "pd-standard".  If SSD persistent disks are
            available, the resource name typically ends with
            "pd-ssd".  The actual valid values are defined
            the Google Compute Engine API, not by the Cloud
            Dataflow API; consult the Google Compute Engine
            documentation for more information about
            determining the set of available disk types for
            a particular project and zone.
            Google Compute Engine Disk types are local to a
            particular project in a particular zone, and so
            the resource name will typically look something
            like this:

            compute.googleapis.com/projects/project-id/zones/zone/diskTypes/pd-standard
        mount_point (str):
            Directory in a VM where disk is mounted.
    """

    size_gb: int = proto.Field(
        proto.INT32,
        number=1,
    )
    disk_type: str = proto.Field(
        proto.STRING,
        number=2,
    )
    mount_point: str = proto.Field(
        proto.STRING,
        number=3,
    )


class WorkerSettings(proto.Message):
    r"""Provides data to pass through to the worker harness.

    Attributes:
        base_url (str):
            The base URL for accessing Google Cloud APIs.
            When workers access Google Cloud APIs, they
            logically do so via relative URLs.  If this
            field is specified, it supplies the base URL to
            use for resolving these relative URLs.  The
            normative algorithm used is defined by RFC 1808,
            "Relative Uniform Resource Locators".

            If not specified, the default value is
            "http://www.googleapis.com/".
        reporting_enabled (bool):
            Whether to send work progress updates to the
            service.
        service_path (str):
            The Cloud Dataflow service path relative to
            the root URL, for example,
            "dataflow/v1b3/projects".
        shuffle_service_path (str):
            The Shuffle service path relative to the root
            URL, for example, "shuffle/v1beta1".
        worker_id (str):
            The ID of the worker running this pipeline.
        temp_storage_prefix (str):
            The prefix of the resources the system should
            use for temporary storage.

            The supported resource type is:

            Google Cloud Storage:

              storage.googleapis.com/{bucket}/{object}
              bucket.storage.googleapis.com/{object}
    """

    base_url: str = proto.Field(
        proto.STRING,
        number=1,
    )
    reporting_enabled: bool = proto.Field(
        proto.BOOL,
        number=2,
    )
    service_path: str = proto.Field(
        proto.STRING,
        number=3,
    )
    shuffle_service_path: str = proto.Field(
        proto.STRING,
        number=4,
    )
    worker_id: str = proto.Field(
        proto.STRING,
        number=5,
    )
    temp_storage_prefix: str = proto.Field(
        proto.STRING,
        number=6,
    )


class TaskRunnerSettings(proto.Message):
    r"""Taskrunner configuration settings.

    Attributes:
        task_user (str):
            The UNIX user ID on the worker VM to use for
            tasks launched by taskrunner; e.g. "root".
        task_group (str):
            The UNIX group ID on the worker VM to use for
            tasks launched by taskrunner; e.g. "wheel".
        oauth_scopes (MutableSequence[str]):
            The OAuth2 scopes to be requested by the
            taskrunner in order to access the Cloud Dataflow
            API.
        base_url (str):
            The base URL for the taskrunner to use when
            accessing Google Cloud APIs.
            When workers access Google Cloud APIs, they
            logically do so via relative URLs.  If this
            field is specified, it supplies the base URL to
            use for resolving these relative URLs.  The
            normative algorithm used is defined by RFC 1808,
            "Relative Uniform Resource Locators".

            If not specified, the default value is
            "http://www.googleapis.com/".
        dataflow_api_version (str):
            The API version of endpoint, e.g. "v1b3".
        parallel_worker_settings (google.cloud.dataflow_v1beta3.types.WorkerSettings):
            The settings to pass to the parallel worker
            harness.
        base_task_dir (str):
            The location on the worker for task-specific
            subdirectories.
        continue_on_exception (bool):
            Whether to continue taskrunner if an
            exception is hit.
        log_to_serialconsole (bool):
            Whether to send taskrunner log info to Google
            Compute Engine VM serial console.
        alsologtostderr (bool):
            Whether to also send taskrunner log info to
            stderr.
        log_upload_location (str):
            Indicates where to put logs.  If this is not
            specified, the logs will not be uploaded.

            The supported resource type is:

            Google Cloud Storage:
              storage.googleapis.com/{bucket}/{object}
              bucket.storage.googleapis.com/{object}
        log_dir (str):
            The directory on the VM to store logs.
        temp_storage_prefix (str):
            The prefix of the resources the taskrunner
            should use for temporary storage.

            The supported resource type is:

            Google Cloud Storage:
              storage.googleapis.com/{bucket}/{object}
              bucket.storage.googleapis.com/{object}
        harness_command (str):
            The command to launch the worker harness.
        workflow_file_name (str):
            The file to store the workflow in.
        commandlines_file_name (str):
            The file to store preprocessing commands in.
        vm_id (str):
            The ID string of the VM.
        language_hint (str):
            The suggested backend language.
        streaming_worker_main_class (str):
            The streaming worker main class name.
    """

    task_user: str = proto.Field(
        proto.STRING,
        number=1,
    )
    task_group: str = proto.Field(
        proto.STRING,
        number=2,
    )
    oauth_scopes: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    base_url: str = proto.Field(
        proto.STRING,
        number=4,
    )
    dataflow_api_version: str = proto.Field(
        proto.STRING,
        number=5,
    )
    parallel_worker_settings: "WorkerSettings" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="WorkerSettings",
    )
    base_task_dir: str = proto.Field(
        proto.STRING,
        number=7,
    )
    continue_on_exception: bool = proto.Field(
        proto.BOOL,
        number=8,
    )
    log_to_serialconsole: bool = proto.Field(
        proto.BOOL,
        number=9,
    )
    alsologtostderr: bool = proto.Field(
        proto.BOOL,
        number=10,
    )
    log_upload_location: str = proto.Field(
        proto.STRING,
        number=11,
    )
    log_dir: str = proto.Field(
        proto.STRING,
        number=12,
    )
    temp_storage_prefix: str = proto.Field(
        proto.STRING,
        number=13,
    )
    harness_command: str = proto.Field(
        proto.STRING,
        number=14,
    )
    workflow_file_name: str = proto.Field(
        proto.STRING,
        number=15,
    )
    commandlines_file_name: str = proto.Field(
        proto.STRING,
        number=16,
    )
    vm_id: str = proto.Field(
        proto.STRING,
        number=17,
    )
    language_hint: str = proto.Field(
        proto.STRING,
        number=18,
    )
    streaming_worker_main_class: str = proto.Field(
        proto.STRING,
        number=19,
    )


class AutoscalingSettings(proto.Message):
    r"""Settings for WorkerPool autoscaling.

    Attributes:
        algorithm (google.cloud.dataflow_v1beta3.types.AutoscalingAlgorithm):
            The algorithm to use for autoscaling.
        max_num_workers (int):
            The maximum number of workers to cap scaling
            at.
    """

    algorithm: "AutoscalingAlgorithm" = proto.Field(
        proto.ENUM,
        number=1,
        enum="AutoscalingAlgorithm",
    )
    max_num_workers: int = proto.Field(
        proto.INT32,
        number=2,
    )


class SdkHarnessContainerImage(proto.Message):
    r"""Defines a SDK harness container for executing Dataflow
    pipelines.

    Attributes:
        container_image (str):
            A docker container image that resides in
            Google Container Registry.
        use_single_core_per_container (bool):
            If true, recommends the Dataflow service to
            use only one core per SDK container instance
            with this image. If false (or unset) recommends
            using more than one core per SDK container
            instance with this image for efficiency. Note
            that Dataflow service may choose to override
            this property if needed.
        environment_id (str):
            Environment ID for the Beam runner API proto
            Environment that corresponds to the current SDK
            Harness.
        capabilities (MutableSequence[str]):
            The set of capabilities enumerated in the above Environment
            proto. See also
            https://github.com/apache/beam/blob/master/model/pipeline/src/main/proto/beam_runner_api.proto
    """

    container_image: str = proto.Field(
        proto.STRING,
        number=1,
    )
    use_single_core_per_container: bool = proto.Field(
        proto.BOOL,
        number=2,
    )
    environment_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    capabilities: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class WorkerPool(proto.Message):
    r"""Describes one particular pool of Cloud Dataflow workers to be
    instantiated by the Cloud Dataflow service in order to perform
    the computations required by a job.  Note that a workflow job
    may use multiple pools, in order to match the various
    computational requirements of the various stages of the job.

    Attributes:
        kind (str):
            The kind of the worker pool; currently only ``harness`` and
            ``shuffle`` are supported.
        num_workers (int):
            Number of Google Compute Engine workers in
            this pool needed to execute the job.  If zero or
            unspecified, the service will attempt to choose
            a reasonable default.
        packages (MutableSequence[google.cloud.dataflow_v1beta3.types.Package]):
            Packages to be installed on workers.
        default_package_set (google.cloud.dataflow_v1beta3.types.DefaultPackageSet):
            The default package set to install.  This
            allows the service to select a default set of
            packages which are useful to worker harnesses
            written in a particular language.
        machine_type (str):
            Machine type (e.g. "n1-standard-1").  If
            empty or unspecified, the service will attempt
            to choose a reasonable default.
        teardown_policy (google.cloud.dataflow_v1beta3.types.TeardownPolicy):
            Sets the policy for determining when to turndown worker
            pool. Allowed values are: ``TEARDOWN_ALWAYS``,
            ``TEARDOWN_ON_SUCCESS``, and ``TEARDOWN_NEVER``.
            ``TEARDOWN_ALWAYS`` means workers are always torn down
            regardless of whether the job succeeds.
            ``TEARDOWN_ON_SUCCESS`` means workers are torn down if the
            job succeeds. ``TEARDOWN_NEVER`` means the workers are never
            torn down.

            If the workers are not torn down by the service, they will
            continue to run and use Google Compute Engine VM resources
            in the user's project until they are explicitly terminated
            by the user. Because of this, Google recommends using the
            ``TEARDOWN_ALWAYS`` policy except for small, manually
            supervised test jobs.

            If unknown or unspecified, the service will attempt to
            choose a reasonable default.
        disk_size_gb (int):
            Size of root disk for VMs, in GB.  If zero or
            unspecified, the service will attempt to choose
            a reasonable default.
        disk_type (str):
            Type of root disk for VMs.  If empty or
            unspecified, the service will attempt to choose
            a reasonable default.
        disk_source_image (str):
            Fully qualified source image for disks.
        zone (str):
            Zone to run the worker pools in.  If empty or
            unspecified, the service will attempt to choose
            a reasonable default.
        taskrunner_settings (google.cloud.dataflow_v1beta3.types.TaskRunnerSettings):
            Settings passed through to Google Compute
            Engine workers when using the standard Dataflow
            task runner.  Users should ignore this field.
        on_host_maintenance (str):
            The action to take on host maintenance, as
            defined by the Google Compute Engine API.
        data_disks (MutableSequence[google.cloud.dataflow_v1beta3.types.Disk]):
            Data disks that are used by a VM in this
            workflow.
        metadata (MutableMapping[str, str]):
            Metadata to set on the Google Compute Engine
            VMs.
        autoscaling_settings (google.cloud.dataflow_v1beta3.types.AutoscalingSettings):
            Settings for autoscaling of this WorkerPool.
        pool_args (google.protobuf.any_pb2.Any):
            Extra arguments for this worker pool.
        network (str):
            Network to which VMs will be assigned.  If
            empty or unspecified, the service will use the
            network "default".
        subnetwork (str):
            Subnetwork to which VMs will be assigned, if
            desired.  Expected to be of the form
            "regions/REGION/subnetworks/SUBNETWORK".
        worker_harness_container_image (str):
            Required. Docker container image that executes the Cloud
            Dataflow worker harness, residing in Google Container
            Registry.

            Deprecated for the Fn API path. Use
            sdk_harness_container_images instead.
        num_threads_per_worker (int):
            The number of threads per worker harness. If
            empty or unspecified, the service will choose a
            number of threads (according to the number of
            cores on the selected machine type for batch, or
            1 by convention for streaming).
        ip_configuration (google.cloud.dataflow_v1beta3.types.WorkerIPAddressConfiguration):
            Configuration for VM IPs.
        sdk_harness_container_images (MutableSequence[google.cloud.dataflow_v1beta3.types.SdkHarnessContainerImage]):
            Set of SDK harness containers needed to
            execute this pipeline. This will only be set in
            the Fn API path. For non-cross-language
            pipelines this should have only one entry.
            Cross-language pipelines will have two or more
            entries.
    """

    kind: str = proto.Field(
        proto.STRING,
        number=1,
    )
    num_workers: int = proto.Field(
        proto.INT32,
        number=2,
    )
    packages: MutableSequence["Package"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="Package",
    )
    default_package_set: "DefaultPackageSet" = proto.Field(
        proto.ENUM,
        number=4,
        enum="DefaultPackageSet",
    )
    machine_type: str = proto.Field(
        proto.STRING,
        number=5,
    )
    teardown_policy: "TeardownPolicy" = proto.Field(
        proto.ENUM,
        number=6,
        enum="TeardownPolicy",
    )
    disk_size_gb: int = proto.Field(
        proto.INT32,
        number=7,
    )
    disk_type: str = proto.Field(
        proto.STRING,
        number=16,
    )
    disk_source_image: str = proto.Field(
        proto.STRING,
        number=8,
    )
    zone: str = proto.Field(
        proto.STRING,
        number=9,
    )
    taskrunner_settings: "TaskRunnerSettings" = proto.Field(
        proto.MESSAGE,
        number=10,
        message="TaskRunnerSettings",
    )
    on_host_maintenance: str = proto.Field(
        proto.STRING,
        number=11,
    )
    data_disks: MutableSequence["Disk"] = proto.RepeatedField(
        proto.MESSAGE,
        number=12,
        message="Disk",
    )
    metadata: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=13,
    )
    autoscaling_settings: "AutoscalingSettings" = proto.Field(
        proto.MESSAGE,
        number=14,
        message="AutoscalingSettings",
    )
    pool_args: any_pb2.Any = proto.Field(
        proto.MESSAGE,
        number=15,
        message=any_pb2.Any,
    )
    network: str = proto.Field(
        proto.STRING,
        number=17,
    )
    subnetwork: str = proto.Field(
        proto.STRING,
        number=19,
    )
    worker_harness_container_image: str = proto.Field(
        proto.STRING,
        number=18,
    )
    num_threads_per_worker: int = proto.Field(
        proto.INT32,
        number=20,
    )
    ip_configuration: "WorkerIPAddressConfiguration" = proto.Field(
        proto.ENUM,
        number=21,
        enum="WorkerIPAddressConfiguration",
    )
    sdk_harness_container_images: MutableSequence[
        "SdkHarnessContainerImage"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=22,
        message="SdkHarnessContainerImage",
    )


class DebugOptions(proto.Message):
    r"""Describes any options that have an effect on the debugging of
    pipelines.

    Attributes:
        enable_hot_key_logging (bool):
            When true, enables the logging of the literal
            hot key to the user's Cloud Logging.
    """

    enable_hot_key_logging: bool = proto.Field(
        proto.BOOL,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.dataflow.v1beta3",
    manifest={
        "TopologyConfig",
        "PubsubLocation",
        "StreamingStageLocation",
        "StreamingSideInputLocation",
        "CustomSourceLocation",
        "StreamLocation",
        "StateFamilyConfig",
        "ComputationTopology",
        "KeyRangeLocation",
        "MountedDataDisk",
        "DataDiskAssignment",
        "KeyRangeDataDiskAssignment",
        "StreamingComputationRanges",
        "StreamingApplianceSnapshotConfig",
    },
)


class TopologyConfig(proto.Message):
    r"""Global topology of the streaming Dataflow job, including all
    computations and their sharded locations.

    Attributes:
        computations (MutableSequence[google.cloud.dataflow_v1beta3.types.ComputationTopology]):
            The computations associated with a streaming
            Dataflow job.
        data_disk_assignments (MutableSequence[google.cloud.dataflow_v1beta3.types.DataDiskAssignment]):
            The disks assigned to a streaming Dataflow
            job.
        user_stage_to_computation_name_map (MutableMapping[str, str]):
            Maps user stage names to stable computation
            names.
        forwarding_key_bits (int):
            The size (in bits) of keys that will be
            assigned to source messages.
        persistent_state_version (int):
            Version number for persistent state.
    """

    computations: MutableSequence["ComputationTopology"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="ComputationTopology",
    )
    data_disk_assignments: MutableSequence["DataDiskAssignment"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="DataDiskAssignment",
    )
    user_stage_to_computation_name_map: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=3,
    )
    forwarding_key_bits: int = proto.Field(
        proto.INT32,
        number=4,
    )
    persistent_state_version: int = proto.Field(
        proto.INT32,
        number=5,
    )


class PubsubLocation(proto.Message):
    r"""Identifies a pubsub location to use for transferring data
    into or out of a streaming Dataflow job.

    Attributes:
        topic (str):
            A pubsub topic, in the form of
            "pubsub.googleapis.com/topics/<project-id>/<topic-name>".
        subscription (str):
            A pubsub subscription, in the form of
            "pubsub.googleapis.com/subscriptions/<project-id>/<subscription-name>".
        timestamp_label (str):
            If set, contains a pubsub label from which to
            extract record timestamps. If left empty, record
            timestamps will be generated upon arrival.
        id_label (str):
            If set, contains a pubsub label from which to
            extract record ids. If left empty, record
            deduplication will be strictly best effort.
        drop_late_data (bool):
            Indicates whether the pipeline allows
            late-arriving data.
        tracking_subscription (str):
            If set, specifies the pubsub subscription
            that will be used for tracking custom time
            timestamps for watermark estimation.
        with_attributes (bool):
            If true, then the client has requested to get
            pubsub attributes.
    """

    topic: str = proto.Field(
        proto.STRING,
        number=1,
    )
    subscription: str = proto.Field(
        proto.STRING,
        number=2,
    )
    timestamp_label: str = proto.Field(
        proto.STRING,
        number=3,
    )
    id_label: str = proto.Field(
        proto.STRING,
        number=4,
    )
    drop_late_data: bool = proto.Field(
        proto.BOOL,
        number=5,
    )
    tracking_subscription: str = proto.Field(
        proto.STRING,
        number=6,
    )
    with_attributes: bool = proto.Field(
        proto.BOOL,
        number=7,
    )


class StreamingStageLocation(proto.Message):
    r"""Identifies the location of a streaming computation stage, for
    stage-to-stage communication.

    Attributes:
        stream_id (str):
            Identifies the particular stream within the
            streaming Dataflow job.
    """

    stream_id: str = proto.Field(
        proto.STRING,
        number=1,
    )


class StreamingSideInputLocation(proto.Message):
    r"""Identifies the location of a streaming side input.

    Attributes:
        tag (str):
            Identifies the particular side input within
            the streaming Dataflow job.
        state_family (str):
            Identifies the state family where this side
            input is stored.
    """

    tag: str = proto.Field(
        proto.STRING,
        number=1,
    )
    state_family: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CustomSourceLocation(proto.Message):
    r"""Identifies the location of a custom souce.

    Attributes:
        stateful (bool):
            Whether this source is stateful.
    """

    stateful: bool = proto.Field(
        proto.BOOL,
        number=1,
    )


class StreamLocation(proto.Message):
    r"""Describes a stream of data, either as input to be processed
    or as output of a streaming Dataflow job.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        streaming_stage_location (google.cloud.dataflow_v1beta3.types.StreamingStageLocation):
            The stream is part of another computation
            within the current streaming Dataflow job.

            This field is a member of `oneof`_ ``location``.
        pubsub_location (google.cloud.dataflow_v1beta3.types.PubsubLocation):
            The stream is a pubsub stream.

            This field is a member of `oneof`_ ``location``.
        side_input_location (google.cloud.dataflow_v1beta3.types.StreamingSideInputLocation):
            The stream is a streaming side input.

            This field is a member of `oneof`_ ``location``.
        custom_source_location (google.cloud.dataflow_v1beta3.types.CustomSourceLocation):
            The stream is a custom source.

            This field is a member of `oneof`_ ``location``.
    """

    streaming_stage_location: "StreamingStageLocation" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="location",
        message="StreamingStageLocation",
    )
    pubsub_location: "PubsubLocation" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="location",
        message="PubsubLocation",
    )
    side_input_location: "StreamingSideInputLocation" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="location",
        message="StreamingSideInputLocation",
    )
    custom_source_location: "CustomSourceLocation" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="location",
        message="CustomSourceLocation",
    )


class StateFamilyConfig(proto.Message):
    r"""State family configuration.

    Attributes:
        state_family (str):
            The state family value.
        is_read (bool):
            If true, this family corresponds to a read
            operation.
    """

    state_family: str = proto.Field(
        proto.STRING,
        number=1,
    )
    is_read: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class ComputationTopology(proto.Message):
    r"""All configuration data for a particular Computation.

    Attributes:
        system_stage_name (str):
            The system stage name.
        computation_id (str):
            The ID of the computation.
        key_ranges (MutableSequence[google.cloud.dataflow_v1beta3.types.KeyRangeLocation]):
            The key ranges processed by the computation.
        inputs (MutableSequence[google.cloud.dataflow_v1beta3.types.StreamLocation]):
            The inputs to the computation.
        outputs (MutableSequence[google.cloud.dataflow_v1beta3.types.StreamLocation]):
            The outputs from the computation.
        state_families (MutableSequence[google.cloud.dataflow_v1beta3.types.StateFamilyConfig]):
            The state family values.
    """

    system_stage_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    computation_id: str = proto.Field(
        proto.STRING,
        number=5,
    )
    key_ranges: MutableSequence["KeyRangeLocation"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="KeyRangeLocation",
    )
    inputs: MutableSequence["StreamLocation"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="StreamLocation",
    )
    outputs: MutableSequence["StreamLocation"] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="StreamLocation",
    )
    state_families: MutableSequence["StateFamilyConfig"] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message="StateFamilyConfig",
    )


class KeyRangeLocation(proto.Message):
    r"""Location information for a specific key-range of a sharded
    computation. Currently we only support UTF-8 character splits to
    simplify encoding into JSON.

    Attributes:
        start (str):
            The start (inclusive) of the key range.
        end (str):
            The end (exclusive) of the key range.
        delivery_endpoint (str):
            The physical location of this range
            assignment to be used for streaming computation
            cross-worker message delivery.
        data_disk (str):
            The name of the data disk where data for this
            range is stored. This name is local to the
            Google Cloud Platform project and uniquely
            identifies the disk within that project, for
            example
            "myproject-1014-104817-4c2-harness-0-disk-1".
        deprecated_persistent_directory (str):
            DEPRECATED. The location of the persistent
            state for this range, as a persistent directory
            in the worker local filesystem.
    """

    start: str = proto.Field(
        proto.STRING,
        number=1,
    )
    end: str = proto.Field(
        proto.STRING,
        number=2,
    )
    delivery_endpoint: str = proto.Field(
        proto.STRING,
        number=3,
    )
    data_disk: str = proto.Field(
        proto.STRING,
        number=5,
    )
    deprecated_persistent_directory: str = proto.Field(
        proto.STRING,
        number=4,
    )


class MountedDataDisk(proto.Message):
    r"""Describes mounted data disk.

    Attributes:
        data_disk (str):
            The name of the data disk.
            This name is local to the Google Cloud Platform
            project and uniquely identifies the disk within
            that project, for example
            "myproject-1014-104817-4c2-harness-0-disk-1".
    """

    data_disk: str = proto.Field(
        proto.STRING,
        number=1,
    )


class DataDiskAssignment(proto.Message):
    r"""Data disk assignment for a given VM instance.

    Attributes:
        vm_instance (str):
            VM instance name the data disks mounted to,
            for example
            "myproject-1014-104817-4c2-harness-0".
        data_disks (MutableSequence[str]):
            Mounted data disks. The order is important a
            data disk's 0-based index in this list defines
            which persistent directory the disk is mounted
            to, for example the list of {
            "myproject-1014-104817-4c2-harness-0-disk-0" },
            { "myproject-1014-104817-4c2-harness-0-disk-1"
            }.
    """

    vm_instance: str = proto.Field(
        proto.STRING,
        number=1,
    )
    data_disks: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class KeyRangeDataDiskAssignment(proto.Message):
    r"""Data disk assignment information for a specific key-range of
    a sharded computation.
    Currently we only support UTF-8 character splits to simplify
    encoding into JSON.

    Attributes:
        start (str):
            The start (inclusive) of the key range.
        end (str):
            The end (exclusive) of the key range.
        data_disk (str):
            The name of the data disk where data for this
            range is stored. This name is local to the
            Google Cloud Platform project and uniquely
            identifies the disk within that project, for
            example
            "myproject-1014-104817-4c2-harness-0-disk-1".
    """

    start: str = proto.Field(
        proto.STRING,
        number=1,
    )
    end: str = proto.Field(
        proto.STRING,
        number=2,
    )
    data_disk: str = proto.Field(
        proto.STRING,
        number=3,
    )


class StreamingComputationRanges(proto.Message):
    r"""Describes full or partial data disk assignment information of
    the computation ranges.

    Attributes:
        computation_id (str):
            The ID of the computation.
        range_assignments (MutableSequence[google.cloud.dataflow_v1beta3.types.KeyRangeDataDiskAssignment]):
            Data disk assignments for ranges from this
            computation.
    """

    computation_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    range_assignments: MutableSequence[
        "KeyRangeDataDiskAssignment"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="KeyRangeDataDiskAssignment",
    )


class StreamingApplianceSnapshotConfig(proto.Message):
    r"""Streaming appliance snapshot configuration.

    Attributes:
        snapshot_id (str):
            If set, indicates the snapshot id for the
            snapshot being performed.
        import_state_endpoint (str):
            Indicates which endpoint is used to import
            appliance state.
    """

    snapshot_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    import_state_endpoint: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .environment import (
    AutoscalingAlgorithm,
    AutoscalingSettings,
    DebugOptions,
    DefaultPackageSet,
    Disk,
    Environment,
    FlexResourceSchedulingGoal,
    JobType,
    Package,
    SdkHarnessContainerImage,
    ShuffleMode,
    TaskRunnerSettings,
    TeardownPolicy,
    WorkerIPAddressConfiguration,
    WorkerPool,
    WorkerSettings,
)
from .jobs import (
    BigQueryIODetails,
    BigTableIODetails,
    CheckActiveJobsRequest,
    CheckActiveJobsResponse,
    CreateJobRequest,
    DatastoreIODetails,
    DisplayData,
    ExecutionStageState,
    ExecutionStageSummary,
    FailedLocation,
    FileIODetails,
    GetJobRequest,
    Job,
    JobExecutionInfo,
    JobExecutionStageInfo,
    JobMetadata,
    JobState,
    JobView,
    KindType,
    ListJobsRequest,
    ListJobsResponse,
    PipelineDescription,
    PubSubIODetails,
    SdkVersion,
    SnapshotJobRequest,
    SpannerIODetails,
    Step,
    TransformSummary,
    UpdateJobRequest,
)
from .messages import (
    AutoscalingEvent,
    JobMessage,
    JobMessageImportance,
    ListJobMessagesRequest,
    ListJobMessagesResponse,
    StructuredMessage,
)
from .metrics import (
    ExecutionState,
    GetJobExecutionDetailsRequest,
    GetJobMetricsRequest,
    GetStageExecutionDetailsRequest,
    JobExecutionDetails,
    JobMetrics,
    MetricStructuredName,
    MetricUpdate,
    ProgressTimeseries,
    StageExecutionDetails,
    StageSummary,
    WorkerDetails,
    WorkItemDetails,
)
from .snapshots import (
    DeleteSnapshotRequest,
    DeleteSnapshotResponse,
    GetSnapshotRequest,
    ListSnapshotsRequest,
    ListSnapshotsResponse,
    PubsubSnapshotMetadata,
    Snapshot,
    SnapshotState,
)
from .streaming import (
    ComputationTopology,
    CustomSourceLocation,
    DataDiskAssignment,
    KeyRangeDataDiskAssignment,
    KeyRangeLocation,
    MountedDataDisk,
    PubsubLocation,
    StateFamilyConfig,
    StreamingApplianceSnapshotConfig,
    StreamingComputationRanges,
    StreamingSideInputLocation,
    StreamingStageLocation,
    StreamLocation,
    TopologyConfig,
)
from .templates import (
    ContainerSpec,
    CreateJobFromTemplateRequest,
    DynamicTemplateLaunchParams,
    FlexTemplateRuntimeEnvironment,
    GetTemplateRequest,
    GetTemplateResponse,
    InvalidTemplateParameters,
    LaunchFlexTemplateParameter,
    LaunchFlexTemplateRequest,
    LaunchFlexTemplateResponse,
    LaunchTemplateParameters,
    LaunchTemplateRequest,
    LaunchTemplateResponse,
    ParameterMetadata,
    ParameterType,
    RuntimeEnvironment,
    RuntimeMetadata,
    SDKInfo,
    TemplateMetadata,
)

__all__ = (
    "AutoscalingSettings",
    "DebugOptions",
    "Disk",
    "Environment",
    "Package",
    "SdkHarnessContainerImage",
    "TaskRunnerSettings",
    "WorkerPool",
    "WorkerSettings",
    "AutoscalingAlgorithm",
    "DefaultPackageSet",
    "FlexResourceSchedulingGoal",
    "JobType",
    "ShuffleMode",
    "TeardownPolicy",
    "WorkerIPAddressConfiguration",
    "BigQueryIODetails",
    "BigTableIODetails",
    "CheckActiveJobsRequest",
    "CheckActiveJobsResponse",
    "CreateJobRequest",
    "DatastoreIODetails",
    "DisplayData",
    "ExecutionStageState",
    "ExecutionStageSummary",
    "FailedLocation",
    "FileIODetails",
    "GetJobRequest",
    "Job",
    "JobExecutionInfo",
    "JobExecutionStageInfo",
    "JobMetadata",
    "ListJobsRequest",
    "ListJobsResponse",
    "PipelineDescription",
    "PubSubIODetails",
    "SdkVersion",
    "SnapshotJobRequest",
    "SpannerIODetails",
    "Step",
    "TransformSummary",
    "UpdateJobRequest",
    "JobState",
    "JobView",
    "KindType",
    "AutoscalingEvent",
    "JobMessage",
    "ListJobMessagesRequest",
    "ListJobMessagesResponse",
    "StructuredMessage",
    "JobMessageImportance",
    "GetJobExecutionDetailsRequest",
    "GetJobMetricsRequest",
    "GetStageExecutionDetailsRequest",
    "JobExecutionDetails",
    "JobMetrics",
    "MetricStructuredName",
    "MetricUpdate",
    "ProgressTimeseries",
    "StageExecutionDetails",
    "StageSummary",
    "WorkerDetails",
    "WorkItemDetails",
    "ExecutionState",
    "DeleteSnapshotRequest",
    "DeleteSnapshotResponse",
    "GetSnapshotRequest",
    "ListSnapshotsRequest",
    "ListSnapshotsResponse",
    "PubsubSnapshotMetadata",
    "Snapshot",
    "SnapshotState",
    "ComputationTopology",
    "CustomSourceLocation",
    "DataDiskAssignment",
    "KeyRangeDataDiskAssignment",
    "KeyRangeLocation",
    "MountedDataDisk",
    "PubsubLocation",
    "StateFamilyConfig",
    "StreamingApplianceSnapshotConfig",
    "StreamingComputationRanges",
    "StreamingSideInputLocation",
    "StreamingStageLocation",
    "StreamLocation",
    "TopologyConfig",
    "ContainerSpec",
    "CreateJobFromTemplateRequest",
    "DynamicTemplateLaunchParams",
    "FlexTemplateRuntimeEnvironment",
    "GetTemplateRequest",
    "GetTemplateResponse",
    "InvalidTemplateParameters",
    "LaunchFlexTemplateParameter",
    "LaunchFlexTemplateRequest",
    "LaunchFlexTemplateResponse",
    "LaunchTemplateParameters",
    "LaunchTemplateRequest",
    "LaunchTemplateResponse",
    "ParameterMetadata",
    "RuntimeEnvironment",
    "RuntimeMetadata",
    "SDKInfo",
    "TemplateMetadata",
    "ParameterType",
)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import struct_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.dataflow.v1beta3",
    manifest={
        "ExecutionState",
        "MetricStructuredName",
        "MetricUpdate",
        "GetJobMetricsRequest",
        "JobMetrics",
        "GetJobExecutionDetailsRequest",
        "ProgressTimeseries",
        "StageSummary",
        "JobExecutionDetails",
        "GetStageExecutionDetailsRequest",
        "WorkItemDetails",
        "WorkerDetails",
        "StageExecutionDetails",
    },
)


class ExecutionState(proto.Enum):
    r"""The state of some component of job execution."""
    EXECUTION_STATE_UNKNOWN = 0
    EXECUTION_STATE_NOT_STARTED = 1
    EXECUTION_STATE_RUNNING = 2
    EXECUTION_STATE_SUCCEEDED = 3
    EXECUTION_STATE_FAILED = 4
    EXECUTION_STATE_CANCELLED = 5


class MetricStructuredName(proto.Message):
    r"""Identifies a metric, by describing the source which generated
    the metric.

    Attributes:
        origin (str):
            Origin (namespace) of metric name. May be
            blank for user-define metrics; will be
            "dataflow" for metrics defined by the Dataflow
            service or SDK.
        name (str):
            Worker-defined metric name.
        context (MutableMapping[str, str]):
            Zero or more labeled fields which identify the part of the
            job this metric is associated with, such as the name of a
            step or collection.

            For example, built-in counters associated with steps will
            have context['step'] = . Counters associated with
            PCollections in the SDK will have context['pcollection'] = .
    """

    origin: str = proto.Field(
        proto.STRING,
        number=1,
    )
    name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    context: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=3,
    )


class MetricUpdate(proto.Message):
    r"""Describes the state of a metric.

    Attributes:
        name (google.cloud.dataflow_v1beta3.types.MetricStructuredName):
            Name of the metric.
        kind (str):
            Metric aggregation kind.  The possible metric
            aggregation kinds are "Sum", "Max", "Min",
            "Mean", "Set", "And", "Or", and "Distribution".
            The specified aggregation kind is
            case-insensitive.
            If omitted, this is not an aggregated value but
            instead a single metric sample value.
        cumulative (bool):
            True if this metric is reported as the total
            cumulative aggregate value accumulated since the
            worker started working on this WorkItem. By
            default this is false, indicating that this
            metric is reported as a delta that is not
            associated with any WorkItem.
        scalar (google.protobuf.struct_pb2.Value):
            Worker-computed aggregate value for
            aggregation kinds "Sum", "Max", "Min", "And",
            and "Or".  The possible value types are Long,
            Double, and Boolean.
        mean_sum (google.protobuf.struct_pb2.Value):
            Worker-computed aggregate value for the "Mean" aggregation
            kind. This holds the sum of the aggregated values and is
            used in combination with mean_count below to obtain the
            actual mean aggregate value. The only possible value types
            are Long and Double.
        mean_count (google.protobuf.struct_pb2.Value):
            Worker-computed aggregate value for the "Mean" aggregation
            kind. This holds the count of the aggregated values and is
            used in combination with mean_sum above to obtain the actual
            mean aggregate value. The only possible value type is Long.
        set_ (google.protobuf.struct_pb2.Value):
            Worker-computed aggregate value for the "Set"
            aggregation kind.  The only possible value type
            is a list of Values whose type can be Long,
            Double, or String, according to the metric's
            type.  All Values in the list must be of the
            same type.
        distribution (google.protobuf.struct_pb2.Value):
            A struct value describing properties of a
            distribution of numeric values.
        gauge (google.protobuf.struct_pb2.Value):
            A struct value describing properties of a
            Gauge. Metrics of gauge type show the value of a
            metric across time, and is aggregated based on
            the newest value.
        internal (google.protobuf.struct_pb2.Value):
            Worker-computed aggregate value for internal
            use by the Dataflow service.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Timestamp associated with the metric value.
            Optional when workers are reporting work
            progress; it will be filled in responses from
            the metrics API.
    """

    name: "MetricStructuredName" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="MetricStructuredName",
    )
    kind: str = proto.Field(
        proto.STRING,
        number=2,
    )
    cumulative: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    scalar: struct_pb2.Value = proto.Field(
        proto.MESSAGE,
        number=4,
        message=struct_pb2.Value,
    )
    mean_sum: struct_pb2.Value = proto.Field(
        proto.MESSAGE,
        number=5,
        message=struct_pb2.Value,
    )
    mean_count: struct_pb2.Value = proto.Field(
        proto.MESSAGE,
        number=6,
        message=struct_pb2.Value,
    )
    set_: struct_pb2.Value = proto.Field(
        proto.MESSAGE,
        number=7,
        message=struct_pb2.Value,
    )
    distribution: struct_pb2.Value = proto.Field(
        proto.MESSAGE,
        number=11,
        message=struct_pb2.Value,
    )
    gauge: struct_pb2.Value = proto.Field(
        proto.MESSAGE,
        number=12,
        message=struct_pb2.Value,
    )
    internal: struct_pb2.Value = proto.Field(
        proto.MESSAGE,
        number=8,
        message=struct_pb2.Value,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=9,
        message=timestamp_pb2.Timestamp,
    )


class GetJobMetricsRequest(proto.Message):
    r"""Request to get job metrics.

    Attributes:
        project_id (str):
            A project id.
        job_id (str):
            The job to get metrics for.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Return only metric data that has changed
            since this time. Default is to return all
            information about all metrics for the job.
        location (str):
            The [regional endpoint]
            (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints)
            that contains the job specified by job_id.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    job_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    location: str = proto.Field(
        proto.STRING,
        number=4,
    )


class JobMetrics(proto.Message):
    r"""JobMetrics contains a collection of metrics describing the
    detailed progress of a Dataflow job. Metrics correspond to
    user-defined and system-defined metrics in the job.

    This resource captures only the most recent values of each
    metric; time-series data can be queried for them (under the same
    metric names) from Cloud Monitoring.

    Attributes:
        metric_time (google.protobuf.timestamp_pb2.Timestamp):
            Timestamp as of which metric values are
            current.
        metrics (MutableSequence[google.cloud.dataflow_v1beta3.types.MetricUpdate]):
            All metrics for this job.
    """

    metric_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    metrics: MutableSequence["MetricUpdate"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="MetricUpdate",
    )


class GetJobExecutionDetailsRequest(proto.Message):
    r"""Request to get job execution details.

    Attributes:
        project_id (str):
            A project id.
        job_id (str):
            The job to get execution details for.
        location (str):
            The [regional endpoint]
            (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints)
            that contains the job specified by job_id.
        page_size (int):
            If specified, determines the maximum number
            of stages to return.  If unspecified, the
            service may choose an appropriate default, or
            may return an arbitrarily large number of
            results.
        page_token (str):
            If supplied, this should be the value of next_page_token
            returned by an earlier call. This will cause the next page
            of results to be returned.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    job_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    location: str = proto.Field(
        proto.STRING,
        number=3,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=4,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ProgressTimeseries(proto.Message):
    r"""Information about the progress of some component of job
    execution.

    Attributes:
        current_progress (float):
            The current progress of the component, in the range [0,1].
        data_points (MutableSequence[google.cloud.dataflow_v1beta3.types.ProgressTimeseries.Point]):
            History of progress for the component.
            Points are sorted by time.
    """

    class Point(proto.Message):
        r"""A point in the timeseries.

        Attributes:
            time (google.protobuf.timestamp_pb2.Timestamp):
                The timestamp of the point.
            value (float):
                The value of the point.
        """

        time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=1,
            message=timestamp_pb2.Timestamp,
        )
        value: float = proto.Field(
            proto.DOUBLE,
            number=2,
        )

    current_progress: float = proto.Field(
        proto.DOUBLE,
        number=1,
    )
    data_points: MutableSequence[Point] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=Point,
    )


class StageSummary(proto.Message):
    r"""Information about a particular execution stage of a job.

    Attributes:
        stage_id (str):
            ID of this stage
        state (google.cloud.dataflow_v1beta3.types.ExecutionState):
            State of this stage.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Start time of this stage.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            End time of this stage.
            If the work item is completed, this is the
            actual end time of the stage. Otherwise, it is
            the predicted end time.
        progress (google.cloud.dataflow_v1beta3.types.ProgressTimeseries):
            Progress for this stage.
            Only applicable to Batch jobs.
        metrics (MutableSequence[google.cloud.dataflow_v1beta3.types.MetricUpdate]):
            Metrics for this stage.
    """

    stage_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    state: "ExecutionState" = proto.Field(
        proto.ENUM,
        number=2,
        enum="ExecutionState",
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    progress: "ProgressTimeseries" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="ProgressTimeseries",
    )
    metrics: MutableSequence["MetricUpdate"] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message="MetricUpdate",
    )


class JobExecutionDetails(proto.Message):
    r"""Information about the execution of a job.

    Attributes:
        stages (MutableSequence[google.cloud.dataflow_v1beta3.types.StageSummary]):
            The stages of the job execution.
        next_page_token (str):
            If present, this response does not contain all requested
            tasks. To obtain the next page of results, repeat the
            request with page_token set to this value.
    """

    @property
    def raw_page(self):
        return self

    stages: MutableSequence["StageSummary"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="StageSummary",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetStageExecutionDetailsRequest(proto.Message):
    r"""Request to get information about a particular execution stage
    of a job. Currently only tracked for Batch jobs.

    Attributes:
        project_id (str):
            A project id.
        job_id (str):
            The job to get execution details for.
        location (str):
            The [regional endpoint]
            (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints)
            that contains the job specified by job_id.
        stage_id (str):
            The stage for which to fetch information.
        page_size (int):
            If specified, determines the maximum number
            of work items to return.  If unspecified, the
            service may choose an appropriate default, or
            may return an arbitrarily large number of
            results.
        page_token (str):
            If supplied, this should be the value of next_page_token
            returned by an earlier call. This will cause the next page
            of results to be returned.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Lower time bound of work items to include, by
            start time.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Upper time bound of work items to include, by
            start time.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    job_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    location: str = proto.Field(
        proto.STRING,
        number=3,
    )
    stage_id: str = proto.Field(
        proto.STRING,
        number=4,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=5,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=6,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=8,
        message=timestamp_pb2.Timestamp,
    )


class WorkItemDetails(proto.Message):
    r"""Information about an individual work item execution.

    Attributes:
        task_id (str):
            Name of this work item.
        attempt_id (str):
            Attempt ID of this work item
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Start time of this work item attempt.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            End time of this work item attempt.
            If the work item is completed, this is the
            actual end time of the work item.  Otherwise, it
            is the predicted end time.
        state (google.cloud.dataflow_v1beta3.types.ExecutionState):
            State of this work item.
        progress (google.cloud.dataflow_v1beta3.types.ProgressTimeseries):
            Progress of this work item.
        metrics (MutableSequence[google.cloud.dataflow_v1beta3.types.MetricUpdate]):
            Metrics for this work item.
    """

    task_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    attempt_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    state: "ExecutionState" = proto.Field(
        proto.ENUM,
        number=5,
        enum="ExecutionState",
    )
    progress: "ProgressTimeseries" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="ProgressTimeseries",
    )
    metrics: MutableSequence["MetricUpdate"] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message="MetricUpdate",
    )


class WorkerDetails(proto.Message):
    r"""Information about a worker

    Attributes:
        worker_name (str):
            Name of this worker
        work_items (MutableSequence[google.cloud.dataflow_v1beta3.types.WorkItemDetails]):
            Work items processed by this worker, sorted
            by time.
    """

    worker_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    work_items: MutableSequence["WorkItemDetails"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="WorkItemDetails",
    )


class StageExecutionDetails(proto.Message):
    r"""Information about the workers and work items within a stage.

    Attributes:
        workers (MutableSequence[google.cloud.dataflow_v1beta3.types.WorkerDetails]):
            Workers that have done work on the stage.
        next_page_token (str):
            If present, this response does not contain all requested
            tasks. To obtain the next page of results, repeat the
            request with page_token set to this value.
    """

    @property
    def raw_page(self):
        return self

    workers: MutableSequence["WorkerDetails"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="WorkerDetails",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.dataflow.v1beta3",
    manifest={
        "SnapshotState",
        "PubsubSnapshotMetadata",
        "Snapshot",
        "GetSnapshotRequest",
        "DeleteSnapshotRequest",
        "DeleteSnapshotResponse",
        "ListSnapshotsRequest",
        "ListSnapshotsResponse",
    },
)


class SnapshotState(proto.Enum):
    r"""Snapshot state."""
    UNKNOWN_SNAPSHOT_STATE = 0
    PENDING = 1
    RUNNING = 2
    READY = 3
    FAILED = 4
    DELETED = 5


class PubsubSnapshotMetadata(proto.Message):
    r"""Represents a Pubsub snapshot.

    Attributes:
        topic_name (str):
            The name of the Pubsub topic.
        snapshot_name (str):
            The name of the Pubsub snapshot.
        expire_time (google.protobuf.timestamp_pb2.Timestamp):
            The expire time of the Pubsub snapshot.
    """

    topic_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    snapshot_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    expire_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )


class Snapshot(proto.Message):
    r"""Represents a snapshot of a job.

    Attributes:
        id (str):
            The unique ID of this snapshot.
        project_id (str):
            The project this snapshot belongs to.
        source_job_id (str):
            The job this snapshot was created from.
        creation_time (google.protobuf.timestamp_pb2.Timestamp):
            The time this snapshot was created.
        ttl (google.protobuf.duration_pb2.Duration):
            The time after which this snapshot will be
            automatically deleted.
        state (google.cloud.dataflow_v1beta3.types.SnapshotState):
            State of the snapshot.
        pubsub_metadata (MutableSequence[google.cloud.dataflow_v1beta3.types.PubsubSnapshotMetadata]):
            Pub/Sub snapshot metadata.
        description (str):
            User specified description of the snapshot.
            Maybe empty.
        disk_size_bytes (int):
            The disk byte size of the snapshot. Only
            available for snapshots in READY state.
        region (str):
            Cloud region where this snapshot lives in,
            e.g., "us-central1".
    """

    id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    project_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    source_job_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    creation_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    ttl: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=5,
        message=duration_pb2.Duration,
    )
    state: "SnapshotState" = proto.Field(
        proto.ENUM,
        number=6,
        enum="SnapshotState",
    )
    pubsub_metadata: MutableSequence["PubsubSnapshotMetadata"] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message="PubsubSnapshotMetadata",
    )
    description: str = proto.Field(
        proto.STRING,
        number=8,
    )
    disk_size_bytes: int = proto.Field(
        proto.INT64,
        number=9,
    )
    region: str = proto.Field(
        proto.STRING,
        number=10,
    )


class GetSnapshotRequest(proto.Message):
    r"""Request to get information about a snapshot

    Attributes:
        project_id (str):
            The ID of the Cloud Platform project that the
            snapshot belongs to.
        snapshot_id (str):
            The ID of the snapshot.
        location (str):
            The location that contains this snapshot.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    snapshot_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    location: str = proto.Field(
        proto.STRING,
        number=3,
    )


class DeleteSnapshotRequest(proto.Message):
    r"""Request to delete a snapshot.

    Attributes:
        project_id (str):
            The ID of the Cloud Platform project that the
            snapshot belongs to.
        snapshot_id (str):
            The ID of the snapshot.
        location (str):
            The location that contains this snapshot.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    snapshot_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    location: str = proto.Field(
        proto.STRING,
        number=3,
    )


class DeleteSnapshotResponse(proto.Message):
    r"""Response from deleting a snapshot."""


class ListSnapshotsRequest(proto.Message):
    r"""Request to list snapshots.

    Attributes:
        project_id (str):
            The project ID to list snapshots for.
        job_id (str):
            If specified, list snapshots created from
            this job.
        location (str):
            The location to list snapshots in.
    """

    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    job_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    location: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListSnapshotsResponse(proto.Message):
    r"""List of snapshots.

    Attributes:
        snapshots (MutableSequence[google.cloud.dataflow_v1beta3.types.Snapshot]):
            Returned snapshots.
    """

    snapshots: MutableSequence["Snapshot"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Snapshot",
    )


__all__ = tuple(sorted(__protobuf__.manifest))
